import React, { useEffect, useMemo, useState } from "react";
import type { BannerType, IBusiness } from "../typings/business";
import type { BannerDataType } from "../data/banner";
import { BANNER_DATA } from "../data/banner";
import { SEGMENT_EVENTS } from "../data/segmentEvents";
import { View, ViewStyle } from "react-native";
import { showMessage } from "react-native-flash-message";
import { COLOR } from "../data/color";
import { RenderBanner } from "../component/Banner/Item";
import { useLMS } from "../context/context";

type OFHeaderProps = {
  onPress?({
    type,
    contractUrl,
  }: {
    type: BannerType;
    contractUrl: string;
  }): void;
  onClose?(): void;
};

export const Banner: React.ComponentType<OFHeaderProps> = ({
  onClose,
  onPress,
}) => {
  const [detail, setDetail] = useState<IBusiness | undefined>();
  const { EMAIL, userDetail } = useLMS();

  const status = useMemo(() => {
    let contractUrl, contractValid, reason;
    if (detail) {
      contractUrl = detail.kyb?.facilities.filter(
        (d: any) => d.status === "contract_pending",
      )[0]?.envelope_url;
      contractValid = detail.kyb?.facilities.filter(
        (d: any) => d.status === "contract_valid",
      );
      reason = detail.kyb?.statuses?.filter(
        (d: any) => d.status === "rejected",
      );
    }
    return {
      contractUrl,
      contractValid,
      reason: reason && reason.length > 0 ? reason[0].reason : "",
    };
  }, [detail]);

  useEffect(() => {
    if (!EMAIL) {
      showMessage({ message: "Email is required", type: "danger" });
    } else {
      setDetail(userDetail);
    }
  }, [EMAIL, userDetail]);

  return (
    <View style={styles.container as ViewStyle}>
      {detail && (
        <View>
          {!detail.kyb && (
            <RenderBanner
              data={BANNER_DATA().REGISTER as BannerDataType}
              color={COLOR.info}
              onPress={onPress}
              onClose={onClose}
              contractUrl={status.contractUrl}
            />
          )}
          {detail?.kyb && detail.kyb?.status === "pending" && (
            <RenderBanner
              data={BANNER_DATA().PENDING as BannerDataType}
              color={COLOR.warning}
              onPress={onPress}
              onClose={onClose}
              contractUrl={status.contractUrl}
            />
          )}
          {detail.kyb &&
            detail.kyb.status === "approved" &&
            status.contractValid?.length === 0 && (
              <RenderBanner
                data={
                  BANNER_DATA(
                    undefined,
                    !status.contractUrl
                      ? "You will receive contract soon"
                      : "Review and sign contract",
                  ).APPROVED as BannerDataType
                }
                color={COLOR.info}
                disabled={!status.contractUrl}
                event={SEGMENT_EVENTS.CLICK_SIGN_CONTRACT}
                onPress={onPress}
                onClose={onClose}
                contractUrl={status.contractUrl}
              />
            )}
          {detail.kyb && detail.kyb.status === "rejected" && (
            <RenderBanner
              data={BANNER_DATA(status?.reason).REJECTED as BannerDataType}
              color={COLOR.error}
              event={SEGMENT_EVENTS.CLICK_KYC_REGISTRATION}
              onPress={onPress}
              onClose={onClose}
              contractUrl={status.contractUrl}
            />
          )}
        </View>
      )}
    </View>
  );
};

const styles = {
  container: {
    flexDirection: "column",
    border: "1px solid red",
    flex: 1,
    height: 400,
    minHeight: 400,
  },
  financeContainer: {
    display: "flex",
    flexDirection: "row",
    width: "100%",
    padding: 12,
    flexWrap: "nowrap",
    alignItems: "center",
    justifyContent: "space-between",
    marginBottom: 5,
  },
  buttonWrapper: {
    display: "flex",
    flexDirection: "row",
  },
  gap: {
    width: 8,
    height: 8,
  },
  wrapper: {
    flexDirection: "column",
  },
  flexRow: {
    display: "flex",
    flexDirection: "row",
  },
  flexCol: {
    display: "flex",
    flexDirection: "column",
  },
};
