import React from "react";
import type { BannerDataType } from "../../data/banner";
import { TouchableOpacity, View, ViewStyle } from "react-native";
import { Button, Text } from "react-native-paper";
import analytics from "../../utils/segment";

import type { BannerType } from "../../typings/business";

type RenderBannerProps = {
  onPress?({
    type,
    contractUrl,
  }: {
    type: BannerType;
    contractUrl: string;
  }): void;
  onClose?(): void;
  color?: any;
  data: BannerDataType;
  disabled?: boolean;
  event?: string;
  contractUrl?: string;
};

export const RenderBanner: React.ComponentType<RenderBannerProps> = ({
  data,
  color,
  disabled,
  event,
  onClose,
  onPress,
  contractUrl,
}) => {
  return (
    <View
      style={{
        ...(styles.financeContainer as ViewStyle),
        backgroundColor: color,
      }}
    >
      <View style={styles.wrapper as ViewStyle}>
        <Text>{data.title}</Text>
        <Text>{data.description}</Text>
        <View style={styles.flexCol as ViewStyle}>
          {data.actionTitle && (
            <Button
              disabled={disabled}
              mode={"contained"}
              onPress={() => {
                onPress?.({
                  type: data.type,
                  contractUrl: contractUrl || "",
                });
              }}
            >
              {data ? data.actionTitle : ""}
            </Button>
          )}
        </View>
      </View>
      <View
        style={{
          ...(styles.flexRow as ViewStyle),
          alignSelf: "flex-start",
          alignItems: "flex-start",
        }}
      >
        {data.actionTitle && (
          <Button
            mode={"contained"}
            disabled={disabled}
            onPress={() => {
              if (event) {
                analytics.track(event);
              }
              onPress?.({
                type: data.type,
                contractUrl: contractUrl || "",
              });
            }}
          >
            {data.actionTitle}
          </Button>
        )}
        <TouchableOpacity
          onPress={() => {
            onClose?.();
          }}
        ></TouchableOpacity>
      </View>
    </View>
  );
};

const styles = {
  container: {
    flexDirection: "column",
    border: "1px solid red",
    flex: 1,
    height: 400,
    minHeight: 400,
  },
  financeContainer: {
    display: "flex",
    flexDirection: "row",
    width: "100%",
    padding: 12,
    flexWrap: "nowrap",
    alignItems: "center",
    justifyContent: "space-between",
    marginBottom: 5,
  },
  buttonWrapper: {
    display: "flex",
    flexDirection: "row",
  },
  gap: {
    width: 8,
    height: 8,
  },
  wrapper: {
    flexDirection: "column",
  },
  flexRow: {
    display: "flex",
    flexDirection: "row",
  },
  flexCol: {
    display: "flex",
    flexDirection: "column",
  },
};
